#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.boswars.org/
#
# This also needs a lua.pc file from the lua source that is not included
# in the lua Zenwalk package for some reason.

# Package name
NAME="boswars"
# Package version
VERSION="2.5"
# Source code URL
SOURCE="http://www.boswars.org/dist/releases/boswars-$VERSION-src.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="CHANGELOG COPYRIGHT.txt LICENSE.txt README.txt doc"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="52.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: boswars - a real-time strategy game
$NAME:
$NAME: Bos Wars is a futuristic real-time strategy game. It is possible to
$NAME: play against human opponents over LAN, internet, or against the
$NAME: computer. Bos Wars aims to create a completely original and fun
$NAME: open source RTS game. 
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION-src
if [ -f $NAME-$VERSION-src.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Check to see if the lua.pc file is present. If it's not, download it
if [ -f lua.pc ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/lua.pc
fi

# Unpack source
tar xvzf $NAME-$VERSION-src.tar.gz
tar xvzf icons.tar.gz

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Bos Wars
Exec=boswars
Terminal=false
Type=Application
Categories=Game;StrategyGame;
Icon=boswars
EOF

# Create a launch script
mkdir -p $PKG/usr/bin
cat > $PKG/usr/bin/boswars <<EOF
#!/bin/sh
cd /usr/share/boswars
./boswars \$@
EOF
chmod a+x $PKG/usr/bin/boswars

# build
cd $NAME-$VERSION-src
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
# Patch for proper library names
sed -i -e 's/lua5.1/lua/' SConstruct 
sed -i -e 's/lualib/liblua/' SConstruct
# And patch for proper flags
sed -i -e 's/-O2/-O2 -march=i486 -mtune=i686/' SConstruct
# Now do build (the PKG_CONFIG_PATH is for the lua.pc file)
PKG_CONFIG_PATH=$PKG_CONFIG_PATH:../ scons

# No install rule, just copying files
mkdir -p $PKG/usr/share/$NAME
cp -a intro boswars campaigns graphics languages maps scripts sounds units video $PKG/usr/share/$NAME

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION-src
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Copy icons to the right place
ICONSIZES="48 32 24 22 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Also add the lua.pc file
cp $CWD/lua.pc $PKG/usr/src/$NAME-$VERSION

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION-src
rm -rf $PKG
